@@ -3,8 +3,8 @@
 import datetime
 
 from Homevee.Cronjob import IntervalCronjob
-from Homevee.DeviceAPI.heating import heating_control
 from Homevee.Helper import Logger
+from Homevee.Manager.ControlManager.ThermostatManager import ThermostatManager
 from Homevee.Utils.Database import Database
 
 
@@ -32,4 +32,4 @@ class HeatingSchemeCronjob(IntervalCronjob):
         for item in results:
             Logger.log(item)
 
-            heating_control(None, item['TYPE'], item['DEVICE_ID'], item['VALUE'], db, check_user=False)
\ No newline at end of file
+            ThermostatManager().heating_control(None, item['TYPE'], item['DEVICE_ID'], item['VALUE'], db, check_user=False)
\ No newline at end of file
