@@ -42,7 +42,7 @@ def get_modes(user, room, type, id, db: Database = None):
                 item = device.get_dict()
                 modi.append(item)
 
-        return {'modi': modi}
+        return modi
 
     else:
         return get_mode(type, id, db)
\ No newline at end of file
