@@ -6,10 +6,13 @@ from pymax.cube import Cube
 from Homevee.Helper import Logger
 from Homevee.Item import Item
 from Homevee.Item.Gateway import Gateway, MAX_CUBE
-from Homevee.Item.Status import *
 from Homevee.Utils.Database import Database
 
 
+class MaxCubeAPI:
+    def __init__(self):
+        return
+
 def get_devices(ip):
     thermostats = []
     try:
@@ -31,18 +34,13 @@ def set_temp(id, value, db: Database = None):
         db = Database()
     gateway = Item.load_from_db(Gateway, MAX_CUBE)
 
-    try:
-        with Cube(gateway.ip) as cube:
-            for room in cube.rooms:
-                for device in room.devices:
-                    if id == device.serial:
-                        result = cube.set_mode_manual(room.room_id, room.rf_address, float(value))
+    with Cube(gateway.ip) as cube:
+        for room in cube.rooms:
+            for device in room.devices:
+                if id == device.serial:
+                    result = cube.set_mode_manual(room.room_id, room.rf_address, float(value))
 
-                        Logger.log(result)
+                    Logger.log(result)
 
-                        db.update("UPDATE MAX_THERMOSTATS SET LAST_TEMP = :temp WHERE ID == :id",
-                                    {'temp': value, 'id': id})
-
-                        return Status(type=STATUS_OK).get_dict()
-    except:
-        return Status(type=STATUS_ERROR).get_dict()
\ No newline at end of file
+                    db.update("UPDATE MAX_THERMOSTATS SET LAST_TEMP = :temp WHERE ID == :id",
+                                {'temp': value, 'id': id})
\ No newline at end of file
