@@ -24,4 +24,4 @@ def get_devices(db):
 
         devices.append(item)
 
-    return {'devices': devices}
\ No newline at end of file
+    return devices
\ No newline at end of file
