@@ -24,4 +24,12 @@ class NoSuchTypeException(Exception):
 
 class NoPermissionException(Exception):
     '''Raised when a user is not allowed to do the given task'''
+    pass
+
+class RoomHasItemsException(Exception):
+    '''Raised when the room that should be deleted has items'''
+    pass
+
+class AlreadyTrainingException(Exception):
+    '''Raised when an AI-agent is already training'''
     pass
\ No newline at end of file
