@@ -13,7 +13,7 @@ class Thermostat(Device):
             db = Database()
         if(self.update_temp(temp)):
             self.mode = temp
-            self.save_to_db(db)
+            self.save(db)
             return True
         return False
 
