@@ -17,13 +17,13 @@ class CalendarManager():
         if db is None:
             db = Database()
         calendar_items = CalendarEntry.load_all_by_date(date)
-        return {'calendar_entries': CalendarEntry.list_to_dict(calendar_items)}
+        return calendar_items
 
     def delete_entry(self, user, id, db: Database = None):
         if db is None:
             db = Database()
         calendar_entry = Item.load_from_db(CalendarEntry, id)
-        return calendar_entry.api_delete(db)
+        return calendar_entry.delete(db)
 
     def add_edit_entry(self, user, entry_id, name, date, start, end, note, address, db: Database = None):
         if db is None:
@@ -39,4 +39,4 @@ class CalendarManager():
         except:
             calendar_entry = CalendarEntry(name, date, start, end, note, address)
 
-        return calendar_entry.api_save(db)
\ No newline at end of file
+        return calendar_entry.save(db)
\ No newline at end of file
