@@ -20,12 +20,12 @@ class ChatManager:
         if db is None:
             db = Database()
         messages = ChatMessage.load_all_by_time(time, limit)
-        return {'messages': ChatMessage.list_to_dict(messages)}
+        return messages
 
     def get_chat_image(self, user, imageid, db: Database = None):
         if db is None:
             db = Database()
-        return
+        return {}
 
     def send_chat_message(self, user, data, db: Database = None):
         """
@@ -37,5 +37,5 @@ class ChatManager:
         """
         if db is None:
             db = Database()
-        message = ChatMessage(user, data)
-        return message.send()
\ No newline at end of file
+        message = ChatMessage(user.username, data)
+        return message.send(db)
\ No newline at end of file
