@@ -2,13 +2,14 @@
 # -*- coding: utf-8 -*-
 import datetime
 import json
+import traceback
 
-from Homevee.DeviceAPI.heating import get_thermostat_info
-from Homevee.Functions.sensor_data import get_sensor_data
 from Homevee.Helper import Logger
 from Homevee.Item.Room import Room
 from Homevee.Manager.CalendarManager import CalendarManager
+from Homevee.Manager.ControlManager.ThermostatManager import ThermostatManager
 from Homevee.Manager.NutritionDataManager import NutritionDataManager
+from Homevee.Manager.SensorDataManager import SensorDataManager
 from Homevee.Manager.WeatherManager import WeatherManager
 from Homevee.Utils.Database import Database
 from Homevee.Utils.DeviceTypes import *
@@ -47,32 +48,11 @@ class DashboardManager():
 
             dashboard_data['dynamic'] = []
 
-            '''
-            dynamic_temp_items = data['dynamic']
-            devices_map = {}
-            dynamic_items = []
-    
-            print dynamic_temp_items
-    
-            for item in dynamic_temp_items:
-                found = False
-    
-                if(item['type'] not in devices_map):
-                    devices_map[item['type']] = []
-    
-                if item['id'] not in devices_map[item['type']]:
-                    devices_map[item['type']].append(item['id'])
-                else:
-                    found = True
-    
-                if not found:
-                    dynamic_items.append(item)
-    
-            print dynamic_items
-            '''
-
             devices_map = {}
             for item in data['dynamic']:
+                if item is None:
+                    continue
+
                 found = False
 
                 if (item['type'] not in devices_map):
@@ -87,8 +67,8 @@ class DashboardManager():
                     dashboard_data['dynamic'].append(self.get_device_info(user, item['type'], item['id']))
 
             return dashboard_data
-
-        return {'result': 'unknownuser'}
+        else:
+            return None
 
     def get_user_dashboard_items(self, user, db: Database = None):
         if db is None:
@@ -98,7 +78,7 @@ class DashboardManager():
         data = user.dashboard_data
 
         if data is None:
-            return {'dashboard': dashboard_array}
+            return dashboard_array
 
         data = json.loads(data)
 
@@ -116,6 +96,9 @@ class DashboardManager():
         Logger.log(dynamic_temp_items)
 
         for item in dynamic_temp_items:
+            if item is None:
+                continue
+
             found = False
 
             if (item['type'] not in devices_map):
@@ -147,20 +130,20 @@ class DashboardManager():
             if static_data['calendar']:
                 calendar_entries = CalendarManager().get_calendar_day_items(user, datetime.datetime.now().strftime("%Y-%m-%d"))
 
-                items = calendar_entries['calendar_entries']
+                items = calendar_entries
 
                 data = None
                 for item in items:
-                    start = datetime.datetime.strptime(item['start'], '%H:%M')
+                    start = datetime.datetime.strptime(item.start, '%H:%M')
                     dnow = datetime.datetime.now()
 
                     if (dnow.time() > start.time()):
                         continue
 
                     if data is None:
-                        data = item['name'] + " um " + item['start']
+                        data = item.name + " um " + item.start
                     else:
-                        data += '\n' + item['name'] + " um " + item['start'] + " Uhr"
+                        data += '\n' + item.name + " um " + item.start + " Uhr"
 
                 if data is None:
                     data = 'Keine Termine heute'
@@ -178,8 +161,8 @@ class DashboardManager():
                 if static_data['nutritionmanager']:
                     data_item = NutritionDataManager().get_user_nutrition_overview(user)
 
-                    if 'nutrition_day_data' in data_item['data']:
-                        calories_left = data_item['data']['nutrition_day_data']['calories_left']
+                    if 'nutrition_day_data' in data_item:
+                        calories_left = data_item['nutrition_day_data']['calories_left']
                         if (calories_left >= 0):
                             text = str(calories_left) + ' Kalorien übrig'
                         else:
@@ -190,54 +173,62 @@ class DashboardManager():
                         dashboard_array.append({'id': 'nutritionmanager',
                                                 'data': "Ernährungsmanager noch nicht eingerichtet"})
         except:
+            if Logger.IS_DEBUG:
+                traceback.print_exc()
             pass
 
         if len(dynamic_items) > 0:
             dashboard_array.append({'id': 'favouritedevices', 'data': None})
 
-        return {'dashboard': dashboard_array}
+        return dashboard_array
 
-    def edit_user_dashboard(self, username, dashboard_data, db: Database = None):
+    def edit_user_dashboard(self, user, dashboard_data, db: Database = None):
         if db is None:
             db = Database()
 
+        try:
+            dashboard_data = json.loads(dashboard_data)
 
-        dashboard_data = json.loads(dashboard_data)
+            #Check duplicates
 
-        #Check duplicates
+            dynamic_temp_items = dashboard_data['dynamic']
+            devices_map = {}
+            dynamic_items = []
 
-        dynamic_temp_items = dashboard_data['dynamic']
-        devices_map = {}
-        dynamic_items = []
+            #Logger.log(dynamic_temp_items)
 
-        Logger.log(dynamic_temp_items)
+            for item in dynamic_temp_items:
+                found = False
 
-        for item in dynamic_temp_items:
-            found = False
+                if (item['type'] not in devices_map):
+                    devices_map[item['type']] = []
 
-            if (item['type'] not in devices_map):
-                devices_map[item['type']] = []
+                if item['id'] not in devices_map[item['type']]:
+                    devices_map[item['type']].append(item['id'])
+                else:
+                    found = True
 
-            if item['id'] not in devices_map[item['type']]:
-                devices_map[item['type']].append(item['id'])
-            else:
-                found = True
+                if not found:
+                    dynamic_items.append(item)
 
-            if not found:
-                dynamic_items.append(item)
+            #Logger.log(dynamic_items)
 
-        Logger.log(dynamic_items)
+            dashboard_data['dynamic'] = dynamic_items
 
-        dashboard_data['dynamic'] = dynamic_items
+            #Check duplicates end
 
-        #Check duplicates end
+            dashboard_data_json = json.dumps(dashboard_data)
 
-        dashboard_data_json = json.dumps(dashboard_data)
+            print(dashboard_data_json)
 
-        db.update("UPDATE USERDATA SET DASHBOARD_DATA = :data WHERE USERNAME == :username",
-                    {'data': dashboard_data_json, 'username': username})
+            db.update("UPDATE USERDATA SET DASHBOARD_DATA = :data WHERE USERNAME == :username",
+                        {'data': dashboard_data_json, 'username': user.username})
 
-        return self.get_user_dashboard(username)
+            return True
+        except:
+            if Logger.IS_DEBUG:
+                traceback.print_exc()
+            return False
 
     def get_user_favourite_devices(self, user, db: Database = None):
         if db is None:
@@ -246,7 +237,7 @@ class DashboardManager():
 
         dynamic_items = data['dynamic']
 
-        Logger.log("data: "+str(data))
+        #Logger.log("data: "+str(data))
 
         fav_array = self.get_dynamic_items(user, dynamic_items)
 
@@ -276,7 +267,7 @@ class DashboardManager():
                 types[item['type']] = []
 
             types[item['type']].append(item['id'])
-            Logger.log(types)
+            #Logger.log(types)
 
         for type in types:
             ids = types[type]
@@ -287,7 +278,7 @@ class DashboardManager():
                     if item is None:
                         continue
 
-                    Logger.log(favourites)
+                    #Logger.log(favourites)
 
                     favourites[int(item['room'])].append(item)
 
@@ -332,7 +323,7 @@ class DashboardManager():
             #Z-Wave
             elif type == ZWAVE_THERMOSTAT:
                 item = db.select_one("SELECT * FROM ZWAVE_THERMOSTATS WHERE THERMOSTAT_ID == :id", {'id': id})
-                data = get_thermostat_info(user, item['RAUM'], type, item['THERMOSTAT_ID'])
+                data = ThermostatManager().get_thermostat_info(user, item['RAUM'], type, item['THERMOSTAT_ID'])
                 device_data = {'name': item['NAME'], 'id': item['THERMOSTAT_ID'],
                         'icon': item['ICON'], 'room': item['RAUM'], 'type': 'heating',
                         'value': data['value'], 'min': data['min'], 'max': data['max'], 'step': 0.5}
@@ -350,7 +341,7 @@ class DashboardManager():
                 item = db.select_one("SELECT * FROM ZWAVE_SENSOREN WHERE ID == :id", {'id': id})
                 device_data = {'name': item['SHORTFORM'], 'id': item['ID'],
                         'icon': item['ICON'], 'room': item['RAUM'], 'type': 'value',
-                               'value': get_sensor_data(user, item['RAUM'], type, id, 1)}
+                               'value': SensorDataManager().get_sensor_data(user, item['RAUM'], type, id, 1)}
             elif type == ZWAVE_SWITCH:
                 item = db.select_one("SELECT * FROM ZWAVE_SWITCHES WHERE THERMOSTAT_ID == :id", {'id': id})
                 device_data = {'name': item['NAME'], 'id': item['THERMOSTAT_ID'],
@@ -359,7 +350,7 @@ class DashboardManager():
             #MAX Cube
             elif type == MAX_THERMOSTAT:
                 item = db.select_one("SELECT * FROM MAX_THERMOSTATS WHERE ID == :id", {'id': id})
-                data = get_thermostat_info(user, item['RAUM'], type, id)
+                data = ThermostatManager().get_thermostat_info(user, item['RAUM'], type, id)
                 device_data = {'name': item['NAME'], 'id': item['ID'], 'room': item['RAUM'], 'type': 'heating',
                         'icon': item['ICON'],
                         'value': data['value'], 'min': data['min'], 'max': data['max'], 'step': 0.5}
@@ -378,7 +369,7 @@ class DashboardManager():
                 item = db.select_one("SELECT * FROM MQTT_SENSORS WHERE ID == :id", {'id': id})
                 device_data = {'name': item['NAME'], 'id': item['ID'],
                                'icon': item['ICON'], 'room': item['ROOM'], 'type': 'value',
-                               'value': get_sensor_data(user, item['ROOM'], type, id, 1)}
+                               'value': SensorDataManager().get_sensor_data(user, item['ROOM'], type, id, 1)}
         except:
             Logger.log("Error loading device")
 
