@@ -17,15 +17,15 @@ class EventManager():
             db = Database()
         events = Event.load_all_from_db_desc_date_by_type(offset, limit, type)
         user.events_last_checked = time.time()
-        user.save_to_db(db)
-        return {'events': Event.list_to_dict(events)}
+        user.save(db)
+        return events
 
     '''Gibt die Anzahl der ungesehenen Ereignisse zurück'''
     def get_unseen_events(self, user, db: Database = None):
         if db is None:
             db = Database()
         count = Event.get_unseen_events(user)
-        return {'eventcount': count}
+        return count
 
     '''Gibt die vorhandenen Ereignis-Typen zurück'''
     def get_event_types(self, db):
@@ -36,11 +36,11 @@ class EventManager():
         for data in results:
             types.append(data['TYPE'])
 
-        return {'types': types}
+        return types
 
     '''Erstellt ein neues Ereignis'''
     def add_event(self, type, text, db: Database = None):
         if db is None:
             db = Database()
         event = Event(text=text, type=type)
-        return event.save_to_db()
\ No newline at end of file
+        return event.save()
\ No newline at end of file
