@@ -1,4 +1,5 @@
 #!flask/bin/python
+import json
 
 from flask import Blueprint, request
 
@@ -17,4 +18,4 @@ def process_data():
 
     print(msg)
 
-    return msg
\ No newline at end of file
+    return json.dumps(msg)
\ No newline at end of file
