@@ -5,7 +5,7 @@ from Homevee.Helper import Logger
 from Homevee.Helper.helper_functions import get_my_ip
 from Homevee.RestAPI.ProcessDataAPI import ProcessDataAPI
 
-app = Flask(__name__)
+app = Flask("Homevee")
 
 #def update_cert(file):
     #cert_data = open(file).read()
@@ -32,8 +32,8 @@ def start_rest_api():
 
     Logger.log("Starting API on "+str(my_ip))
 
-    app.run(host=my_ip, port=8080)#, debug=True)
-    # app.run(host=HOST, port=443, ssl_context=(FULLCHAIN_FILE, KEY_FILE))
+    app.run(threaded=True, host=my_ip, port=8080)
+    # app.run(threaded=True, host=HOST, port=443, ssl_context=(FULLCHAIN_FILE, KEY_FILE))
 
 if __name__ == '__main__':
     start_rest_api()
\ No newline at end of file
